From 2965a981b7ec22866fbdf2d567d87e2d068d3617 Mon Sep 17 00:00:00 2001
From: Thomas Bruederli <thomas@roundcube.net>
Date: Fri, 31 Jul 2015 16:04:08 -0400
Subject: [PATCH] Allow to search and import missing PGP pubkeys from keyservers using Publickey.js

---
 program/lib/Roundcube/rcube_storage.php |   12 +++++++-----
 1 files changed, 7 insertions(+), 5 deletions(-)

diff --git a/program/lib/Roundcube/rcube_storage.php b/program/lib/Roundcube/rcube_storage.php
index ccb28c6..23e6577 100644
--- a/program/lib/Roundcube/rcube_storage.php
+++ b/program/lib/Roundcube/rcube_storage.php
@@ -492,22 +492,24 @@
     /**
      * Returns the whole message source as string (or saves to a file)
      *
      * @param int      $uid Message UID
      * @param resource $fp  File pointer to save the message
      *
      * @return string Message source string
      */
-    abstract function get_raw_body($uid, $fp = null);
+    abstract function get_raw_body($uid, $fp = null, $part = null);
 
 
     /**
      * Returns the message headers as string
      *
      * @param int $uid  Message UID
      *
      * @return string Message headers string
      */
-    abstract function get_raw_headers($uid);
+    abstract function get_raw_headers($uid, $part = null);
 
 
     /**
@@ -492,22 +492,24 @@
      * Returns the whole message source as string (or saves to a file)
      *
-     * @param int      $uid Message UID
-     * @param resource $fp  File pointer to save the message
+     * @param int      $uid  Message UID
+     * @param resource $fp   File pointer to save the message
+     * @param string   $part Optional message part ID
      *
      * @return string Message source string
@@ -492,22 +492,24 @@
      * Returns the message headers as string
      *
-     * @param int $uid  Message UID
+     * @param int    $uid  Message UID
+     * @param string $part Optional message part ID
      *
      * @return string Message headers string

--
Gitblit v1.9.1